@@ -7,7 +7,9 @@
 
 ;;; Code:
 
-(defconst phps-mode-macrotime-debug nil
+(defconst
+  phps-mode-macrotime-debug
+  nil
   "Debug messages during macro expansion time, default nil.")
 
 (defmacro phps-mode-debug-message (&rest message)
